@@ -335,6 +335,7 @@ display_introduction_message (gpointer data)
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (intro),
 					       gnome_canvas_rich_text_get_type (),
 					       "text", introduction_messages[intro_i],
+						"editable", FALSE,
 					       /* FIXME */
 					       "width", 300.0,
 					       "height", 80.0,
@@ -684,6 +685,7 @@ get_description_messages (xmlNodePtr node)
 				cur = xmlNodeGetLang (paras);
 
 				tmp = strip_newlines (value);
+
 				if (!started) {
 					started = TRUE;
 					if (!cur) {
@@ -724,9 +726,11 @@ get_description_messages (xmlNodePtr node)
 				}
 				g_free (tmp);
 				xmlFree (cur);
+				xmlFree (best);
 			}
 
 			paras = paras->next;
+			xmlFree (value);
 		}
 		list = g_slist_prepend (list, best_value);
 		started = FALSE;
@@ -741,23 +745,32 @@ get_description_messages (xmlNodePtr node)
 
 	introduction_messages[i] = NULL;
 
+	g_free (best_value);
 	g_slist_free (list);
 }
 
 static char*
 create_date_string (const char *value)
 {
-	struct tm tm;
-	char *result;
-	GDate *date = g_date_new ();
+	char  *result;
+	GDate *date;
+	int    day;
+	int    month;
+	int    year;
 
-	if (!strptime (value, "%Y-%m-%d", &tm)) {
+	/* YYYY-MM-DD */
+	if (sscanf (value, "%d-%d-%d", &year, &month, &day) < 3)
 		return NULL;
-	}
-	g_date_set_dmy (date, tm.tm_mday, 1 + tm.tm_mon, 1900 + tm.tm_year);
+
+	date = g_date_new ();
+
+	g_date_set_dmy (date, day, month, year);
+
 	result = g_new0 (char, 20);
 	g_date_strftime (result, 20, "%x", date);
+
 	g_date_free (date);
+
 	return result;
 }
 
@@ -826,6 +839,7 @@ display_version_info (GnomeCanvasGroup *group)
 			build_date_string = create_date_string (value);
 
 		bits = bits->next;
+		xmlFree (value);
 	}
 
 	xmlFreeDoc (about);
